==> dl.php?src=linea21_1_1.zip: linea21/languages/fr/lang_common.utf-8.php <==
<?php

// //////////////////////////////////////////////////
// Linea 21 - PHP language FR
// configuration des langues des modules
// create : 19/06/07
// last_modify : 20/06/07
// creative commons 2007 
//http://creativecommons.org/licenses/by-nc-sa/2.0/fr/legalcode
// //////////////////////////////////////////////////
/**
* lang_FR.php
* 
* @package linea21
* @author anthony 
* @copyright Copyright (c) green-box 2003
* @version 1.0
* @access public 
*/



/**
* 
* Pour modifier les langues de l'interface publique
* modifier aussi config/define_release.php
*
*/


/*	nommage des modules pour menu
*  	*/
$lang['menu']['general'] = "Administration générale";
$lang['menu']['theme'] = "Gestion des thèmes";
$lang['menu']['scale'] = "Gestion des échelles";
$lang['menu']['level'] = "Gestion des niveaux";
$lang['menu']['user'] = "Gestion des utilisateurs";
$lang['menu']['news'] = "Gestion des actualités";
$lang['menu']['newsletter'] = "Gestion des newsletters";
$lang['menu']['yellowpages'] = "Gestion de l'annuaire";
$lang['menu']['workshop'] = "Gestion groupes de travail";
$lang['menu']['publication'] = "Gestion des publications";	
$lang['menu']['sdi'] = "Gestion des indicateurs";
$lang['menu']['forum'] = "Gestion des forums";
$lang['menu']['item'] = "Item sélectionné";
$lang['menu']['search'] = "Recherche";
$lang['menu']['advancedsearch'] = "recherche avancée";
$lang['menu']['dashboard'] = "Gestion du tableau de bord";


/*	nommage des modules
*  	*/
$lang['name']['news_module'] = "actualité";
$lang['name']['publication_module'] = "dossier";
$lang['name']['det_publication_module'] = "partie de dossier";
$lang['name']['workshop_module'] = "groupe de travail";
$lang['name']['workshoprep_module'] = "rapport de groupes de travail";
$lang['name']['workshoprepcon_module'] = "partie de rapport de groupes de travail";
$lang['name']['workshopcal_module'] = "calendrier";
$lang['name']['workshopcom_module'] = "discussion";
$lang['name']['sdi_module'] = 'indicateur de développement durable';


/*	nommage header
*  	*/
$lang['header']['title']= "Linea 21, Votre espace d'administration";
$lang['header']['welcome']= "Bienvenue";
$lang['header']['deconnexion']= "déconnexion";
$lang['header']['deconnexion_title']= "se déconnecter";
$lang['header']['myaccount']="Mon compte";
$lang['header']['myaccount_title']="s'identifier et/ou accéder à mon compte";
$lang['header']['goto_contents']="Aller au contenu";

/*	nommage chemin
*  	*/
$lang['way']['home']= "Accueil";
$lang['recap']['title']="Récapitulatif des informations saisies"; 

/*	action bouton
*  	*/
$lang['btn']['valid']= "valider";
$lang['btn']['save']= "enregistrer";
$lang['btn']['annul']= "annuler";
$lang['btn']['preview']= "revoir les paramètres";
/*	statut

*  	*/
$lang['statut']['draft']='non publié';
$lang['statut']['draftpdf']='non public';
$lang['statut']['published_on']="publié le";
$lang['statut']['archived_on']="archivé le";
$lang['statut']['public']="Public";
$lang['statut']['E']="Supprimé";
$lang['statut']['AA']="Archive administrateur";
$lang['statut']['PA']="Archive publique";
$lang['statut']['W']="en attente - planifié";
$lang['statut']['C']="Clos";
$lang['statut']['U']="Utilisateur";
$lang['statut']['O']="Organisateur";
$lang['statut']['A']="Administrateur";



/*	divers
*  	*/
$lang['divers']['yes']='oui';
$lang['divers']['no']='non';
$lang['divers']['nc']='n.c.';
$lang['divers']['none']='aucun';
$lang['divers']['actions']='actions';
$lang['divers']['no_comment']='aucun commentaire';
$lang['divers']['nodata']='aucune donnée';
$lang['divers']['novisu']="aucun visuel associé";
$lang['divers']['see_visual']='voir le visuel';
$lang['divers']['last_modify']="dernière modification le";
$lang['divers']['date_crea']="date de création";
$lang['divers']['date_sup']="date de suppression";
$lang['divers']['date_publi']="date de publication";
$lang['divers']['sup_confirm']="Demande de confirmation de suppression";
$lang['divers']['statut']="statut";
$lang['divers']['range']="rang";
$lang['divers']['query_result']="Résultat de votre requête";
$lang['divers']['record']="enregistrement";
$lang['divers']['records']="enregistrements";
$lang['divers']['version']="Linea 21 espace d'administration : version ".LINEA_VERSION." / CC 2007 ";
$lang['divers']['select_choice']="~~ Faites votre choix dans la liste ci dessous ~~";
$lang['divers']['select_choice2']="~~ Faites votre choix ~~";
$lang['divers']['enlarge_photo']='agrandir la photo';
$lang['divers']['by']="par";
$lang['divers']['goto_archives']='consulter les archives';
$lang['divers']['goto_currentlist']='retour à la liste courante';
$lang['divers']['page']='page';
$lang['divers']['seconds']='secondes';
$lang['divers']['back_public']='aller à l\'interface publique';
$lang['divers']['backpage']='Page précédente';

/* system
************************/
$lang['divers']['cookies']='Désolé, les cookies doivent être activés pour changer les styles.';
$lang['divers']['redirect_string']='Vous allez être redirigé sur %s dans %d secondes.';


/*	security
*  	*/
$lang['security']['info']="Pour plus de sécurité, veuillez recopier le code ci contre";
$lang['security']['info2']="Recopier ce code dans le champs prévu à cet effet";
$lang['security']['message']="Le code de sécurité entré est incorrect ! Veuillez tenir compte de la casse.";


/*	aide
*  	*/
$lang['help']['name']="Aide";
$lang['help']['title']="Besoin d'aide ? cliquez ici";
$lang['help']['img']="Besoin d'aide ? cliquez ici";
$lang['help']['contact']="Pour toutes questions relatives à l'administration linea21";
$lang['help']['support']="contactez notre support"; 

/*	interface publique
*  	*/
$lang['divers']['level']="Niveau ";
$lang['divers']['scale']="Echelle ";
$lang['divers']['themeref']="Thème ";

$lang['divers']['level_choice']="Trié par niveau ";
$lang['divers']['scale_choice']="Trié par échelle ";
$lang['divers']['themeref_choice']="Trié par thème ";
$lang['divers']['actu_left']="Actualités";
$lang['divers']['sdi_left']="Les derniers indicateurs";
$lang['divers']['contact']="Contact";
$lang['divers']['accessibility']="Charte d'accessibilité";
$lang['divers']['print']="Imprimer cette page";

$lang['divers']['sousthemeref']="Sous thème ";
$lang['divers']['trialpha']="Trié par ordre alphabétique";
$lang['divers']['nodata']="Aucune donnée n'est disponible actuellement";
$lang['divers']['newsletter_public_comment']='L\'abonnement à la newsletter permet de recevoir les dernières actualités, et d\'autres informations directement dans votre boîte e-mail.';

/*	check date
*  	*/
$lang['date']['birthdate_cannotexists'] = 'La date de naissance entrée n\'existe pas.';
$lang['date']['year_overflow'] = 'Votre année de naissance est .... impressionante.';
$lang['date']['year_strlen'] = 'Vous devez saisir votre année de naissance sur 4 chiffres.';
$lang['date']['month_overflow'] = 'Le mois entré pour votre date de naissance n\'existe pas.';
$lang['date']['day_overflow'] = 'Le jour entré pour votre date de naissance n\'existe pas.';


/*	authentification
*  	*/
$lang['divers']['auth']="s'authentifier";
$lang['divers']['noauth']="Vous n'êtes pas authentifié.";
$lang['divers']['creaauth']="Pour vous authentifier ou vous créer un compte ";
$lang['divers']['errorauth']="Un problème est survenu lors de votre authentification, veuillez vous reconnecter.";
$lang['divers']['user_inscription']="S'inscrire";
$lang['divers']['user_inscription_title']="créer mon compte";
$lang['divers']['login']="Identifiant";
$lang['divers']['password']="Mot de passe";
$lang['divers']['email']="email";
$lang['divers']['errorauth']="Identifiant ou mot de passe incorrect";
$lang['divers']['errorauthadmin']="Vous n'avez pas les droits d'administration sur ce module";
/**
$lang['divers']['auth_mess1']="Pour une connexion en tant qu'administrateur (gestion du site entière) :<br />
- identifiant : adminuser<br />
- mot de passe : adminuser<br />
<br />
Pour une connexion en tant que rédacteur (gestion des publications, actualités et tableau de bord) :<br />
- identifiant : redacteur<br />
- mot de passe : redacteur<br /><br />";
*/
$lang['divers']['auth_mess1']="Pour accéder à l'interface d'administration, vous devez activer les cookies dans votre navigateur.";
$lang['divers']['auth_mess2']="Vous avez perdu votre mot de passe ? contactez l'administrateur ici : ";
?>

==> dl.php?src=linea21_1_3_1.zip: linea21/languages/fr/lang_common.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules pour menu
*  	*/
$lang['menu']['general'] = "Administration générale";
$lang['menu']['theme'] = "Gestion des thèmes";
$lang['menu']['scale'] = "Gestion des échelles";
$lang['menu']['level'] = "Gestion des niveaux";
$lang['menu']['user'] = "Gestion des utilisateurs";
$lang['menu']['news'] = "Gestion des actualités";
$lang['menu']['newsletter'] = "Gestion des newsletters";
$lang['menu']['yellowpages'] = "Gestion de l'annuaire";
$lang['menu']['workshop'] = "Gestion groupes de travail";
$lang['menu']['publication'] = "Gestion des publications";	
$lang['menu']['sdi'] = "Gestion des indicateurs";
$lang['menu']['project'] = "Gestion des projets";
$lang['menu']['forum'] = "Gestion des forums";
$lang['menu']['item'] = "Item sélectionné";
$lang['menu']['search'] = "Recherche";
$lang['menu']['advancedsearch'] = "recherche avancée";
$lang['menu']['dashboard'] = "Gestion du tableau de bord";
$lang['menu']['system'] = "Configuration";
$lang['menu']['tools'] = "Outils";

/*	nommage des modules
*  	*/
$lang['name']['news_module'] = "actualité";
$lang['name']['publication_module'] = "dossier";
$lang['name']['det_publication_module'] = "partie de dossier";
$lang['name']['workshop_module'] = "groupe de travail";
$lang['name']['workshoprep_module'] = "rapport de groupes de travail";
$lang['name']['workshoprepcon_module'] = "partie de rapport de groupes de travail";
$lang['name']['workshopcal_module'] = "calendrier";
$lang['name']['workshopcom_module'] = "discussion";
$lang['name']['sdi_module'] = 'indicateur de développement durable';

/*	nommage datePicker
*  	*/
$lang['datePicker']['TEXT_PREV_YEAR']= "Année précédente";
$lang['datePicker']['TEXT_PREV_MONTH']= "Mois précédent";
$lang['datePicker']['TEXT_NEXT_YEAR']= "Année suivante";
$lang['datePicker']['TEXT_NEXT_MONTH']= "Mois suivant";
$lang['datePicker']['TEXT_CLOSE']= "Fermer";
$lang['datePicker']['TEXT_CHOOSE_DATE']= "Choisir la date";

/*	nommage header
*  	*/
$lang['header']['title']= "Linea 21, Votre espace d'administration";
$lang['header']['welcome']= "Bienvenue";
$lang['header']['deconnexion']= "déconnexion";
$lang['header']['deconnexion_title']= "se déconnecter";
$lang['header']['myaccount']="Mon compte";
$lang['header']['myaccount_title']="s'identifier et/ou accéder à mon compte";
$lang['header']['goto_contents']="Aller au contenu";

/*	nommage chemin
*  	*/
$lang['way']['home']= "Accueil";
$lang['recap']['title']="Récapitulatif des informations saisies"; 

/*	action bouton
*  	*/
$lang['btn']['valid']= "valider";
$lang['btn']['save']= "enregistrer";
$lang['btn']['annul']= "annuler";
$lang['btn']['preview']= "revoir les paramètres";

/*	statut

*  	*/
$lang['statut']['draft']='non publié';
$lang['statut']['draftpdf']='non public';
$lang['statut']['published_on']="publié le";
$lang['statut']['archived_on']="archivé le";
$lang['statut']['public']="Public";
$lang['statut']['E']="Supprimé";
$lang['statut']['AA']="Archive administrateur";
$lang['statut']['PA']="Archive publique";
$lang['statut']['W']="en attente - planifié";
$lang['statut']['C']="Clos";
$lang['statut']['U']="Utilisateur";
$lang['statut']['O']="Organisateur";
$lang['statut']['A']="Administrateur";



/*	divers
*  	*/
$lang['divers']['yes']='oui';
$lang['divers']['no']='non';
$lang['divers']['nc']='n.c.';
$lang['divers']['none']='aucun';
$lang['divers']['actions']='actions';
$lang['divers']['no_comment']='aucun commentaire';
$lang['divers']['nodata']='aucune donnée';
$lang['divers']['novisu']="aucun visuel associé";
$lang['divers']['see_visual']='voir le visuel';
$lang['divers']['last_modify']="dernière modification le";
$lang['divers']['date_crea']="date de création";
$lang['divers']['date_sup']="date de suppression";
$lang['divers']['date_publi']="date de publication";
$lang['divers']['sup_confirm']="Demande de confirmation de suppression";
$lang['divers']['statut']="statut";
$lang['divers']['range']="rang";
$lang['divers']['query_result']="Résultat de votre requête";
$lang['divers']['record']="enregistrement";
$lang['divers']['records']="enregistrements";
$lang['divers']['version']="Linea 21 espace d'administration : version ".LINEA_VERSION ;
$lang['divers']['select_choice']="~~ Faites votre choix dans la liste ci dessous ~~";
$lang['divers']['select_choice2']="~~ Faites votre choix ~~";
$lang['divers']['enlarge_photo']='photo agrandie (après click)';
$lang['divers']['by']="par";
$lang['divers']['goto_archives']='consulter les archives';
$lang['divers']['goto_currentlist']='retour à la liste principale';
$lang['divers']['page']='page';
$lang['divers']['seconds']='secondes';
$lang['divers']['back_public']='aller à l\'interface publique';
$lang['divers']['backpage']='Page précédente';
$lang['divers']['licence']='application sous licence %s';
$lang['divers']['select_all']='sélectionner tout';
$lang['divers']['modify']='Modifier';
$lang['divers']['delete']='Supprimer';
$lang['divers']['permalink']='permalink';
$lang['divers']['404']="La page demandée n'exsite pas!";

/* system
************************/
$lang['divers']['cookies']='Désolé, les cookies doivent être activés pour changer les styles.';
$lang['divers']['redirect_string']='Vous allez être redirigé sur %s dans %d secondes.';
$lang['divers']['sql_connect_failed']='La connexion au serveur SQL a échouée';
$lang['divers']['db_connect_failed']='La connexion à la base de données a échouée';
$lang['divers']['sql_query_failed']='Echec de la requête SQL';

/*	security
*  	*/
$lang['antispam']['info']="Anti-spam";
$lang['security']['info']="Pour plus de sécurité, veuillez recopier le code ci contre";
$lang['security']['info2']="Recopier ce code dans le champs prévu à cet effet";
$lang['security']['message']="Le code de sécurité entré est incorrect ! Veuillez tenir compte de la casse.";


/*	aide
*  	*/
$lang['help']['name']="Aide";
$lang['help']['title']="Besoin d'aide ? cliquez ici";
$lang['help']['img']="Besoin d'aide ? cliquez ici";
$lang['help']['contact']="Pour toutes questions relatives à l'administration linea21";
$lang['help']['support']="contactez notre support"; 

/*	interface publique
*  	*/
$lang['divers']['level']="Niveau ";
$lang['divers']['scale']="Echelle ";
$lang['divers']['themeref']="Thème ";

$lang['divers']['priority_choice']="Trié par priorité ";
$lang['divers']['level_choice']="Trié par niveau ";
$lang['divers']['scale_choice']="Trié par échelle ";
$lang['divers']['themeref_choice']="Trié par thème ";
$lang['divers']['actu_left']="Actualités";
$lang['divers']['sdi_left']="Les derniers indicateurs";
$lang['divers']['contact']="Contact";
$lang['divers']['accessibility']="Charte d'accessibilité";
$lang['divers']['print']="Imprimer cette page";

$lang['divers']['sousthemeref']="Sous thème ";
$lang['divers']['trialpha']="Trié par ordre alphabétique";
$lang['divers']['nodata']="Aucune donnée n'est disponible actuellement";
$lang['divers']['newsletter_public_comment']='L\'abonnement à la newsletter permet de recevoir les dernières actualités, et d\'autres informations directement dans votre boîte e-mail.';
$lang['newsletter']['unsubscribe']= 'désinscription';


/*	check date
*  	*/
$lang['date']['not_valid'] = 'La date saisie est incorrecte (format : '. DATE_FORMAT.')';
$lang['date']['date_do_not_exist'] = 'La date saisie n\'existe pas.';

/*	authentification
*  	*/
$lang['divers']['auth']="s'authentifier";
$lang['divers']['noauth']="Vous n'êtes pas authentifié.";
$lang['divers']['creaauth']="Pour vous authentifier ou vous créer un compte ";
$lang['divers']['errorauth']="Un problème est survenu lors de votre authentification, veuillez vous reconnecter.";
$lang['divers']['user_inscription']="S'inscrire";
$lang['divers']['user_inscription_title']="créer mon compte";
$lang['divers']['login']="Identifiant";
$lang['divers']['password']="Mot de passe";
$lang['divers']['email']="email";
$lang['divers']['errorauth']="Identifiant ou mot de passe incorrect";
$lang['divers']['errorauthadmin']="Vous n'avez pas les droits d'administration sur ce module";
/**
$lang['divers']['auth_mess1']="Pour une connexion en tant qu'administrateur (gestion du site entière) :<br />
- identifiant : adminuser<br />
- mot de passe : adminuser<br />
<br />
Pour une connexion en tant que rédacteur (gestion des publications, actualités et tableau de bord) :<br />
- identifiant : redacteur<br />
- mot de passe : redacteur<br /><br />";
*/
$lang['divers']['title_login']="Accédez à l'espace d'administration Linea21";
$lang['divers']['auth_mess1']="Pour accéder à l'interface d'administration, vous devez activer les cookies dans votre navigateur.";
$lang['divers']['auth_mess2']="Vous avez perdu votre mot de passe ? contactez l'administrateur ici : ";

$lang['public']['edito']="Dans une logique de transparence, Linea21 met à disposition un système de
publication ainsi qu'un outil de gestion d'indicateurs de développement durable.
L'application s'adresse, dans sa partie cliente, aux collectivités gérant un
agenda21 et se destine, en terme de communication, à tous les citoyens.
<br /><br />Linea21, outil innovant d'aide à la gestion et à la mise en place d'agenda21.
<br />Pour l'élu : elle traduit ses choix politiques et stratégiques en matière
d'environnement et de développement durable sur l'échelle d'exercice de ces
fonctions.<br /><br />";

$lang['public']['workgroup_h1']="Les groupes de travail";
$lang['public']['workgroup_edito']="S'impliquer et prendre part. Nous vous invitons à participer et intégrer un groupe de travail afin de concentrer les réflexions sur les problèmatiques du développement durable.";
$lang['public']['dashboard_h1']="Le tableau de bord";
$lang['public']['last_news_h1']="Nos Dernières publications";
$lang['public']['dashboard_edito']="Disposez des dernières valeurs des indicateurs de développement durable sur votre commune. Notre tableau de bord d'indicateurs est mis à jour régulierement.";

$lang['check_update']['dl']='La version %s est disponible. Télécharger';
$lang['check_update']['ok']='Votre version est à jour';
$lang['check_update']['search']='Recherche de mise à jour';
$lang['debug']['enabled']='est activé.';

/**
 * CSS Switcher
 */
$lang['css_switcher']['nostyle'] = 'aucun style';
$lang['css_switcher']['default'] = 'classique';
$lang['css_switcher']['minimal'] = 'minimal';
$lang['css_switcher']['darkstyle'] = 'blanc sur noir';

/*	nommage des modules autre style blue_linea
*  	*/
$lang['menu_alt']['general'] = "Administration générale";
$lang['menu_alt']['theme'] = "thèmes";
$lang['menu_alt']['scale'] = "échelles";
$lang['menu_alt']['level'] = "niveaux";
$lang['menu_alt']['user'] = "utilisateurs";
$lang['menu_alt']['news'] = "actualités";
$lang['menu_alt']['newsletter'] = "newsletters";
$lang['menu_alt']['yellowpages'] = "annuaire";
$lang['menu_alt']['workshop'] = "groupes de travail";
$lang['menu_alt']['publication'] = "publications";	
$lang['menu_alt']['sdi'] = "indicateurs";
$lang['menu_alt']['project'] = "projets";
$lang['menu_alt']['forum'] = "forums";
$lang['menu_alt']['dashboard'] = "tableau de bord";
$lang['menu_alt']['system'] = "système";
$lang['menu_alt']['tools'] = "outils";
$lang['menu_alt']['communication'] = "communiquer";
$lang['menu_alt']['suivi_gestion'] = "suivre &amp; gérer";
$lang['menu_alt']['configuration'] = "configurer";
$lang['menu_alt']['interface_publique'] = "interface publique";
$lang['menu_alt']['search_here'] = "Votre recherche ici...";
$lang['menu_alt']['valid_login'] = "Accéder à Linea21";
$lang['menu_alt']['all'] = "dans le site entier";
?>
